#
# spec file for package kseexpr
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 4
%bcond_without released
Name:           kseexpr
Version:        4.0.4.0
Release:        bp156.3.9
Summary:        The embeddable expression engine fork for Krita
License:        GPL-3.0-or-later AND Apache-2.0 AND BSD-3-Clause AND MIT
Group:          Productivity/Graphics/Other
URL:            https://invent.kde.org/graphics/kseexpr/
Source0:        https://download.kde.org/stable/%{name}/4.0.4/%{name}-%{version}.tar.gz
%if %{with released}
Source1:        https://download.kde.org/stable/%{name}/4.0.4/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
%endif
BuildRequires:  extra-cmake-modules
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Widgets)

%description
This is the fork of Disney Animation's SeExpr expression
library (https://wdas.github.io/SeExpr), that is used in Krita.

SeExpr is an embeddable, arithmetic expression language
that enables flexible artistic control and customization
in creating computer graphics images. Example uses
include procedural geometry synthesis, image synthesis,
simulation control, crowd animation, and geometry deformation.

%package -n libKSeExpr%{sover}
Summary:        %{name} libraries
Group:          System/Libraries
# for the lang package to be installable
Provides:       %{name} = %{version}

%description  -n libKSeExpr%{sover}
Runtime libraries for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libKSeExpr%{sover} = %{version}

%description devel
Development headers and libraries for %{name}.

%lang_package

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%if %{with released}
%find_lang seexpr2 %{name}.lang --with-qt
%endif

%post -n libKSeExpr%{sover} -p /sbin/ldconfig
%postun -n libKSeExpr%{sover} -p /sbin/ldconfig

%files -n libKSeExpr%{sover}
%license LICENSES/*
%{_libdir}/libKSeExpr.so.%{sover}
%{_libdir}/libKSeExpr.so.%{sover}.*
%{_libdir}/libKSeExprUI.so.%{sover}
%{_libdir}/libKSeExprUI.so.%{sover}.*

%files devel
%{_datadir}/pkgconfig/kseexpr.pc
%{_includedir}/KSeExpr/
%{_includedir}/KSeExprUI/
%{_libdir}/cmake/KSeExpr/
%{_libdir}/libKSeExpr.so
%{_libdir}/libKSeExprUI.so

%if %{with released}
%files lang -f %{name}.lang
%endif

%changelog
* Tue Dec 21 2021 Wolfgang Bauer <wbauer@tmo.at>
- Rename %%lang option to %%released to pass Factory review
* Wed Dec 15 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 4.0.4.0
  * Add support for LLVM 13
  * Fix copy-paste typo in range comment parsing (kde#442853)
  * ExprEditor: replace index for line/column when reporting errors
  * Reject malformed curve and ccurve calls at parse time
  * Do not look LLVM up unless explicitly enabled
- Add signature file and keyring
* Tue Jul 13 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 4.0.3.0
  * Update the UI parser to enable string variables (kde#439292)
  * Comment parsing: fix skipping the first character after #\s+
  * ExprEditor: disconnect the correct signal
  * Fix typo in LLVM support
  * Insert new variables at the start of the current line
    (kde#439260)
  * Fix mixed up translations (kde#439257)
  * Complete removal of float_t and double_t from function
    signatures (kde#431436)
  * VectorControl: fix valueChanged connect signature
  * ExprCurve, ExprColorCurve: add missing label on interpolation
    type (kde#439263)
  * ExprAddDialog: fix alignment of Default label for String
    variables
  * Insert new variables above the current line (kde#439260)
  * Insert variable name assignment with string types (kde#439259)
  * Interpolate Image Editor root via Qt's native path handling
  * Docstrings typo fixes (kde#439257)
  * Do not use float/double_t types for C++17 utils (kde#431436)
  * Fix SOVERSION (kde#429320)
  * i18n: load translations for ki18n's fallback languages
    (kde#438836)
  * Add support for LLVM 12
  * Add compatibility with VFX 2019
- Drop Fix-possible-compiler-error.patch, fixed upstream
* Thu Jun 10 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 4.0.2.0
  * Fix charconv support with MSVC/GCC11 (kde#437890)
  * Remove unnecessary parameters in CMakeLists
  * Fix translation lookup in stock Linux deployments (kde#429782)
  * Make reproducible tarballs
  * Add support for LLVM 11
- Drop patches merged upstream:
  * Fix-translation-lookup-in-stock-Linux-deployments.patch
  * 0001-Fix-charconv-support-with-MSVC-GCC11.patch
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add GCC 11 build fix (kde#437890):
  * 0001-Fix-charconv-support-with-MSVC-GCC11.patch
* Wed Jan 13 2021 Wolfgang Bauer <wbauer@tmo.at>
- Initial package
- Add Fix-translation-lookup-in-stock-Linux-deployments.patch to
  fix loading the translations (kde#429782)
- Add Fix-possible-compiler-error.patch to fix compiler errors on
  i586 (kde#431436)
